summaryrefslogtreecommitdiff
path: root/src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java')
-rw-r--r--src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java b/src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java
index 9f658b0a..d5fe6219 100644
--- a/src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java
+++ b/src/de/lmu/ifi/dbs/elki/datasource/parser/SparseFloatVectorLabelParser.java
@@ -75,10 +75,11 @@ public class SparseFloatVectorLabelParser extends SparseNumberVectorLabelParser<
*
* @param colSep Column separator
* @param quoteChar Quotation character
* @param labelIndices Label indexes
*/
- public SparseFloatVectorLabelParser(Pattern colSep, char quoteChar, BitSet labelIndices) {
- super(colSep, quoteChar, labelIndices, SparseFloatVector.FACTORY);
+ public SparseFloatVectorLabelParser(Pattern colSep, char quoteChar, Pattern comment, BitSet labelIndices) {
+ super(colSep, quoteChar, comment, labelIndices, SparseFloatVector.FACTORY);
}
/**
@@ -91,7 +92,7 @@ public class SparseFloatVectorLabelParser extends SparseNumberVectorLabelParser<
public static class Parameterizer extends SparseNumberVectorLabelParser.Parameterizer<SparseFloatVector> {
@Override
protected SparseFloatVectorLabelParser makeInstance() {
- return new SparseFloatVectorLabelParser(colSep, quoteChar, labelIndices);
+ return new SparseFloatVectorLabelParser(colSep, quoteChar, comment, labelIndices);
}
}
} \ No newline at end of file
@@ -75,10 +75,11 @@ public class SparseFloatVectorLabelParser extends SparseNumberVectorLabelParser<
* @param colSep Column separator
* @param quoteChar Quotation character
- * @param labelIndices Label indexes
+ * @param comment Comment pattern
+ * @param labelIndices Indices to use as labels
*/